diff mbox

Support for VLAN tags

Message ID 5130BFA4.1020802@linux.vnet.ibm.com
State Accepted
Headers show

Commit Message

Santiago Leon March 1, 2013, 2:48 p.m. UTC
Adds support for booting from an IPv4 or IPv6 network with a VLAN tag.

Signed-off-by: Santiago Leon <santil@linux.vnet.ibm.com>
---
 include/file.h |    1 +
 second/file.c  |   10 +++++++++-
 second/fs_of.c |   11 +++++++++--
 3 files changed, 19 insertions(+), 3 deletions(-)
diff mbox

Patch

diff --git a/include/file.h b/include/file.h
index b2d9c63..e2ccc13 100644
--- a/include/file.h
+++ b/include/file.h
@@ -47,6 +47,7 @@  struct boot_fspec_t {
 	char*	tftp_retries;	/* TFTP retries */
 	char*	subnetmask;	/* Subnet mask */
 	char*	addl_params;	/* copy all additional parameters */
+	char*	vtag;		/* VLAN tag */
 
 	/* Following fields are used only in ipv6 format */
 	int	is_ipv6;	/* is ipv6 specified ? */
diff --git a/second/fs_of.c b/second/fs_of.c
index 77113b1..3a8819c 100644
--- a/second/fs_of.c
+++ b/second/fs_of.c
@@ -152,9 +152,9 @@  of_net_open(struct boot_file_t* file,
      }
 
      DEBUG_F("siaddr <%s>; filename <%s>; ciaddr <%s>; giaddr <%s>;"
-             " ipv6 <%d>\n",
+             " ipv6 <%d>; vtag <%s>\n",
              fspec->siaddr, filename, fspec->ciaddr, fspec->giaddr,
-             fspec->is_ipv6);
+             fspec->is_ipv6, fspec->vtag);
 
      strncpy(buffer, fspec->dev, 768);
      /* If we didn't get a ':' include one */
@@ -169,6 +169,13 @@  of_net_open(struct boot_file_t* file,
      DEBUG_F("Using %s tftp style\n", (new_tftp? "new": "old"));
 
      if (new_tftp) {
+          if (fspec->is_ipv6)
+	       strcat(buffer, "ipv6,");
+
+          if (fspec->vtag) {
+	       strcat(buffer, fspec->vtag);
+	       strcat(buffer, ",");
+	  }
           strcat(buffer, fspec->siaddr);
           strcat(buffer, ",");
diff --git a/second/file.c b/second/file.c
index fd081a3..02b1872 100644
--- a/second/file.c
+++ b/second/file.c
@@ -163,9 +163,14 @@  extract_ipv4_args(char *imagepath, struct boot_fspec_t *result)
 	  args++; /* If comma(,) is not immediately followed by ':' then go past the , */
 
      /*
       * read the arguments in order: siaddr,filename,ciaddr,giaddr,
       * bootp-retries,tftp-retries,addl_prameters
       */
+     if ((tmp = strstr(imagepath, "vtag=")) != NULL) {
+	result->vtag = scopy(&str, &tmp);
+	args = tmp;
+     }
+
      result->siaddr = is_valid_ipv4_str(scopy(&str, &args));
      result->file = scopy(&str, &args);
      result->ciaddr = is_valid_ipv4_str(scopy(&str, &args));
@@ -331,6 +336,9 @@  extract_ipv6_args(char *imagepath, struct boot_fspec_t *result)
      if ((tmp = strstr(imagepath, "dhcpv6=")) != NULL)
 	result->dhcpv6 = scopy(&str, &tmp);
 
+     if ((tmp = strstr(imagepath, "vtag=")) != NULL)
+	result->vtag = scopy(&str, &tmp);
+
      if ((tmp = strstr(imagepath, "ciaddr=")) != NULL)
 	result->ciaddr = scopy(&str, &tmp);
 
@@ -163,9 +163,14 @@  extract_ipv4_args(char *imagepath, struct boot_fspec_t *result)
 
      /*
-      * read the arguments in order: siaddr,filename,ciaddr,giaddr,
+      * read the arguments in order: vtag,siaddr,filename,ciaddr,giaddr,
       * bootp-retries,tftp-retries,addl_prameters
       */